==> jodd-all-3.9-sources.jar: jodd/db/debug/LoggableCallableStatementFactory.java <==
// Copyright (c) 2003-present, Jodd Team (http://jodd.org)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jodd.db.debug;

import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.SQLException;

public class LoggableCallableStatementFactory extends BaseLoggableFactory<CallableStatement> {

	public LoggableCallableStatementFactory() {
		super(CallableStatement.class);
	}

	public CallableStatement prepareCall(Connection connection, String sql, int type, int concurrencyType, int holdability) throws SQLException {
		CallableStatement callableStatement = connection.prepareCall(sql, type, concurrencyType, holdability);
		return wrap(callableStatement, sql);
	}

	public CallableStatement prepareCall(Connection connection, String sql, int type, int concurrencyType) throws SQLException {
		CallableStatement callableStatement = connection.prepareCall(sql, type, concurrencyType);
		return wrap(callableStatement, sql);
	}
}

==> jodd-all-4.1.1-sources.jar: jodd/db/debug/LoggableCallableStatementFactory.java <==
// Copyright (c) 2003-present, Jodd Team (http://jodd.org)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jodd.db.debug;

import java.sql.CallableStatement;
import java.sql.Connection;
import java.sql.SQLException;

public class LoggableCallableStatementFactory extends BaseLoggableFactory<CallableStatement> {

	public LoggableCallableStatementFactory() {
		super(CallableStatement.class);
	}

	public CallableStatement prepareCall(final Connection connection, final String sql, final int type, final int concurrencyType, final int holdability) throws SQLException {
		CallableStatement callableStatement = connection.prepareCall(sql, type, concurrencyType, holdability);
		return wrap(callableStatement, sql);
	}

	public CallableStatement prepareCall(final Connection connection, final String sql, final int type, final int concurrencyType) throws SQLException {
		CallableStatement callableStatement = connection.prepareCall(sql, type, concurrencyType);
		return wrap(callableStatement, sql);
	}
}
